==> huaweicloudsdkcloudtest-3.1.110-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/alarm_statistics_query.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AlarmStatisticsQuery:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'end_time': 'int',
        'start_time': 'int'
    }

    attribute_map = {
        'end_time': 'end_time',
        'start_time': 'start_time'
    }

    def __init__(self, end_time=None, start_time=None):
        """AlarmStatisticsQuery

        The model defined in huaweicloud sdk

        :param end_time: 结束时间
        :type end_time: int
        :param start_time: 开始时间
        :type start_time: int
        """
        
        

        self._end_time = None
        self._start_time = None
        self.discriminator = None

        if end_time is not None:
            self.end_time = end_time
        if start_time is not None:
            self.start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this AlarmStatisticsQuery.

        结束时间

        :return: The end_time of this AlarmStatisticsQuery.
        :rtype: int
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this AlarmStatisticsQuery.

        结束时间

        :param end_time: The end_time of this AlarmStatisticsQuery.
        :type end_time: int
        """
        self._end_time = end_time

    @property
    def start_time(self):
        """Gets the start_time of this AlarmStatisticsQuery.

        开始时间

        :return: The start_time of this AlarmStatisticsQuery.
        :rtype: int
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this AlarmStatisticsQuery.

        开始时间

        :param start_time: The start_time of this AlarmStatisticsQuery.
        :type start_time: int
        """
        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlarmStatisticsQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcloudtest-3.1.151-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/alarm_statistics_query.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AlarmStatisticsQuery:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'end_time': 'int',
        'start_time': 'int'
    }

    attribute_map = {
        'end_time': 'end_time',
        'start_time': 'start_time'
    }

    def __init__(self, end_time=None, start_time=None):
        r"""AlarmStatisticsQuery

        The model defined in huaweicloud sdk

        :param end_time: 结束时间
        :type end_time: int
        :param start_time: 开始时间
        :type start_time: int
        """
        
        

        self._end_time = None
        self._start_time = None
        self.discriminator = None

        if end_time is not None:
            self.end_time = end_time
        if start_time is not None:
            self.start_time = start_time

    @property
    def end_time(self):
        r"""Gets the end_time of this AlarmStatisticsQuery.

        结束时间

        :return: The end_time of this AlarmStatisticsQuery.
        :rtype: int
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        r"""Sets the end_time of this AlarmStatisticsQuery.

        结束时间

        :param end_time: The end_time of this AlarmStatisticsQuery.
        :type end_time: int
        """
        self._end_time = end_time

    @property
    def start_time(self):
        r"""Gets the start_time of this AlarmStatisticsQuery.

        开始时间

        :return: The start_time of this AlarmStatisticsQuery.
        :rtype: int
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        r"""Sets the start_time of this AlarmStatisticsQuery.

        开始时间

        :param start_time: The start_time of this AlarmStatisticsQuery.
        :type start_time: int
        """
        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlarmStatisticsQuery):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
